@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-
+"""Module containing custom templatetags."""
 from django import template
 
 register = template.Library()
@@ -7,8 +6,8 @@ register = template.Library()
 
 @register.filter(name="format_float_dot_delimiter")
 def format_float_dot_delimiter(value):
-    """
-    Ensures that the float value has '.' as the decimal delimiter.
+    """Ensure that the float value has '.' as the decimal delimiter.
+
     This prevents errors caused by internationalisation where it is not wanted,
     i.e. 'de' where the decimal delimiter is ',' and not '.' .
 
@@ -16,7 +15,7 @@ def format_float_dot_delimiter(value):
     Parameters
     ----------
     value : float
-        Arbitrary float value that should be formated
+        Arbitrary float value that should be formatted
 
     Returns
     -------
@@ -24,5 +23,4 @@ def format_float_dot_delimiter(value):
         String representation of the float value,
         with the decimal delimiter.
     """
-
     return str(value)
